@@ -6,6 +6,9 @@
 import logging
 import os
 from pathlib import Path
+import pkg_resources
+import sys
+import platform
 from . import constant as constant
 
 
@@ -35,3 +38,20 @@ def init_log(log_file, create_file=True):
         logger.propagate = False
 
     return logger
+
+
+def init_log_item(main_package_name="", path_to_analyze= ""):
+
+    _PYTHON_VERSION = sys.version_info[0]
+    _result_log = {
+        "Tool Info": main_package_name,
+        "Python version": _PYTHON_VERSION,
+        "OS": platform.system()+" "+platform.release(),
+    }
+    if main_package_name != "":
+        pkg_version = pkg_resources.get_distribution(main_package_name).version
+        _result_log["Tool Info"] = main_package_name +" v."+pkg_version
+    if path_to_analyze != "":
+       _result_log["Path to analyze"] = path_to_analyze
+
+    return _result_log
